package com.lcs.muscle.iogateway;

public class MessageIOGatewayFactory 
{
   // This class is a factory and shouldn't be created anywhere
   private MessageIOGatewayFactory() 
   {
     // empty
   }
   
   public static AbstractMessageIOGateway getMessageIOGateway() 
   {
      return MessageIOGatewayFactory.getMessageIOGateway(AbstractMessageIOGateway.MUSCLE_MESSAGE_DEFAULT_ENCODING);
   }
   
   public static AbstractMessageIOGateway getMessageIOGateway(int encoding) 
   {
      if (encoding == AbstractMessageIOGateway.MUSCLE_MESSAGE_DEFAULT_ENCODING) return new MessageIOGateway();

      // else, try to get the best zlib implementation currently available
      try {
         if (Class.forName("com.jcraft.jzlib.JZlib") != null)
         {
            // Found the JZlib library on the classpath, now return a reference to JZLibMessageIOGateway
            Class gatewayClass = Class.forName("com.lcs.muscle.iogateway.JZLibMessageIOGateway");
            return (AbstractMessageIOGateway) gatewayClass.getConstructor(new Class[] {Integer.TYPE}).newInstance(new Object[] {new Integer(encoding)});
         }
      } catch (Exception e) {
         // If any problems occur, we will fall back to the native class!
      } 
      return new NativeZLibMessageIOGateway(encoding);
   }
}
